package
Version:
v1.0.7
Opens a new window with list of versions in this module.
Published: Feb 25, 2026
License: MPL-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ListTags struct {
Items []*Tag
}
type Tag struct {
Key string `json:"key"`
Value string `json:"value"`
SystemTag bool `json:"systemTag"`
ResourceID string `json:"resourceId"`
TagID string `json:"tagId"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.